from pymusement.parks.universal.UniversalStudiosFlorida import UniversalStudiosFlorida
from pymusement.parks.universal.IslandsOfAdventure import IslandsOfAdventure
from pymusement.parks.universal.UniversalHollywood import UniversalHollywood
from pymusement.parks.universal.UniversalVolcano import UniversalVolcano
from pymusement.parks.HersheyPark import HersheyPark


PARKS = {
    'universal-florida' : UniversalStudiosFlorida(),
    'islands-adventure' : IslandsOfAdventure(),
    'universal-hollywood' : UniversalHollywood(),
    'volcano-bay' : UniversalVolcano(),
    'hersheypark' : HersheyPark()
}



from pymusement.attraction import Attraction
class Show(Attraction):

    _added_keys = ['showtimes', 'endtimes']

    def __init__(self):
        self._addKeys(self._added_keys)
        super(Show, self).__init__()

    def addTime(self, time):
        if self['showtimes'] is None:
            self['showtimes'] = [time]

        else:
            self['showtimes'].append(time)
    def addEnd(self, time):
        if self['endtimes'] is None:
            self['endtimes'] = [time]

        else:
            self['endtimes'].append(time)
    def getTimes(self):
        return self['showtimes'], self['endtimes']



import datetime

# Required to supress some insecure cert warnings
# Normally, this is bad.
import requests

class Park(object):
    def __init__(self):
        self._rides = []
        self._shows = []
        self._time = datetime.datetime.now()

    def rides(self):
        if self._rides == []:
            self._buildPark()
        return self._rides

    def update_time(self):
        return self._time

    def shows(self):
        if self._shows == []:
            self._buildPark()
        return self._shows

    def addRide(self, ride):
        self._rides.append(ride)

    def addShow(self, show):
        self._shows.append(show)

    def setName(self, name):
        self.name = name

    def getName(self):
        raise('This must be implemented')

    def _buildPark(self):
        raise('This must be implemented')
